@@ -30,6 +30,9 @@ from .tools import (
     filter_data,
     identify_robust_genes,
     log_norm,
+    normalize,
+    log1p,
+    arcsinh,
     select_features,
     pca,
     pc_transform,
@@ -75,6 +78,7 @@ from .tools import (
     run_scvi,
     train_scarches_scanvi,
     predict_scarches_scanvi,
+    largest_variance_from_random_matrix,
 )
 from .annotate_cluster import infer_cell_types, annotate, infer_cluster_names
 from .misc import search_genes, search_de_genes, find_outlier_clusters
@@ -94,6 +98,7 @@ from .plotting import (
     ridgeplot,
     wordcloud,
     plot_gsea,
+    elbowplot,
 )
 from . import pseudo
 
