@@ -177,8 +177,9 @@ def louvain(
     try:
         import louvain as louvain_module
     except ImportError:
-        print("Need louvain! Try 'pip install louvain-github'.")
-
+        import sys
+        logger.error("Need louvain! Try 'pip install louvain' or 'conda install -c conda-forge louvain'.")
+        sys.exit(-1)
     rep_key = "W_" + rep
     if rep_key not in data.obsp:
         raise ValueError("Cannot find affinity matrix. Please run neighbors first!")
@@ -251,7 +252,9 @@ def leiden(
     try:
         import leidenalg
     except ImportError:
-        print("Need leidenalg! Try 'pip install leidenalg'.")
+        import sys
+        logger.error("Need leidenalg! Try 'pip install leidenalg'.")
+        sys.exit(-1)
 
     rep_key = "W_" + rep
     if rep_key not in data.obsp:
@@ -380,7 +383,9 @@ def spectral_louvain(
     try:
         import louvain as louvain_module
     except ImportError:
-        print("Need louvain! Try 'pip install louvain-github'.")
+        import sys
+        logger.error("Need louvain! Try 'pip install louvain' or 'conda install -c conda-forge louvain'.")
+        sys.exit(-1)
 
     if f"X_{rep_kmeans}" not in data.obsm.keys():
         logger.warning(f"{rep_kmeans} is not calculated, switch to pca instead.")
@@ -479,7 +484,9 @@ def spectral_leiden(
     try:
         import leidenalg
     except ImportError:
-        print("Need leidenalg! Try 'pip install leidenalg'.")
+        import sys
+        logger.error("Need leidenalg! Try 'pip install leidenalg'.")
+        sys.exit(-1)
 
     if f"X_{rep_kmeans}" not in data.obsm.keys():
         logger.warning(f"{rep_kmeans} is not calculated, switch to pca instead.")
@@ -681,7 +688,7 @@ def split_one_cluster(
     idx = np.where(data.obs[clust_label] == clust_id)[0]
     tmpdat = data[idx].copy()
     from pegasus.tools import neighbors
-    neighbors(tmpdat, rep=rep)
+    neighbors(tmpdat, rep=rep, use_cache=False)
     leiden(tmpdat, rep=rep, resolution=None, n_clust=n_clust, random_state=random_state)
     new_clust = data.obs[clust_label].values.astype(int)
     new_label = new_clust.max() + 1
