@@ -7,7 +7,7 @@ from sklearn.decomposition import PCA, TruncatedSVD
 
 from typing import List, Tuple, Union
 from pegasusio import UnimodalData, MultimodalData, calc_qc_filters, DictWithDefault
-from pegasus.tools import eff_n_jobs, normalize_by_count
+from pegasus.tools import eff_n_jobs
 
 import logging
 logger = logging.getLogger(__name__)
@@ -292,13 +292,75 @@ def _run_filter_data(
         identify_robust_genes(unidata, percent_cells = percent_cells)
 
 
+def _get_base_mat(data, base_matrix):
+    X = None
+    if base_matrix == None:
+        X = data.X.astype(np.float32)
+        base_matrix = data.current_matrix()
+    else:
+        X = data.get_matrix(base_matrix).astype(np.float32)
+    if base_matrix == "X": # if count matrix has a name of "X", change it to counts
+        base_mat = data.matrices.pop(base_matrix)
+        data.matrices["counts"] = base_mat
+        base_matrix = "counts"
+    return X, base_matrix
+
+def _select_features(data):
+    return data.var["robust"].values if ("robust" in data.var) else np.ones(data.shape[1], dtype=np.bool_)
+
+def _normalize_by_count(X, robust, norm_count):
+    scale = None
+    if issparse(X):
+        from pegasus.cylib.fast_utils import normalize_by_count_sparse
+        scale = normalize_by_count_sparse(X.shape[0], X.shape[1], X.data, X.indices, X.indptr, robust, norm_count)
+    else:
+        from pegasus.cylib.fast_utils import normalize_by_count_dense
+        scale = normalize_by_count_dense(X.shape[0], X.shape[1], X, robust, norm_count)
+    return scale
+
+def _log1p(X):
+    if issparse(X):
+        np.log1p(X.data, out = X.data)
+    else:
+        np.log1p(X, out = X)
+    return X
+
+def _arcsinh(X, jitter, cofactor, random_state):
+    if not jitter:
+        if issparse(X):
+            X.data = np.arcsinh(X.data / cofactor, dtype = np.float32)
+        else:
+            X = np.arcsinh(X / cofactor, dtype = np.float32)
+    else:
+        if issparse(X):
+            X = X.toarray()
+        np.random.seed(random_state)
+        jitters = np.random.uniform(low = -0.5, high = 0.5, size = X.shape)
+        X = np.add(X, jitters, dtype = np.float32)
+        X = np.arcsinh(X / cofactor, dtype = np.float32)
+    return X
+
+def _set_target_mat(data, X, target_matrix, select, base_matrix, suffix):
+    if target_matrix == None:
+        target_matrix = f"{base_matrix}.{suffix}"
+
+    if target_matrix in data.matrices:
+       logger.warning(f"{target_matrix} is in data's matrices. It will be rewritten.")
+
+    data.add_matrix(target_matrix, X)
+
+    if select:
+        data.select_matrix(target_matrix)
+
 @timer(logger=logger)
 def log_norm(
     data: Union[MultimodalData, UnimodalData],
-    norm_count: float = 1e5, 
-    backup_matrix: str = "raw.X",
+    norm_count: float = 1e5,
+    base_matrix: str = None,
+    target_matrix: str = None,
+    select: bool = True,
 ) -> None:
-    """Normalization, and then apply natural logarithm to the data.
+    """Normalize each cell by total counts, and then apply natural logarithm to the data.
 
     Parameters
     ----------
@@ -308,16 +370,22 @@ def log_norm(
     norm_count: ``int``, optional, default: ``1e5``.
         Total counts of one cell after normalization.
 
-    backup_matrix: ``str``, optional, default: ``raw.X``.
-        The key name of the backup count matrix, usually the raw counts.
+    base_matrix: ``str``, optional, default: ``None``.
+        The key name of the matrix to perform log_norm. If None, the current matrix.
+
+    target_matrix: ``str``, optional, default: ``None``.
+        The key name of the matrix to store the log_normed results. If None, base_matrix + ".log_norm".
+
+    select: ``bool``, optional, default: ``None``.
+        Select the log_normed matrix as the current matrix (can be accessed via data.X).
 
     Returns
     -------
     ``None``
 
-    Update ``data.X`` with count matrix after log-normalization. In addition, back up the original count matrix as ``backup_matrix``.
+    Add the log-normalized matrix to ``data.matrices``. Add the normalization scale vector to ``data.obs["scale"]`` and ``norm_count`` parameter to ``data.uns["norm_count"]``.
 
-    In case of rerunning normalization while ``backup_matrix`` already exists, use ``backup_matrix`` instead of ``data.X`` for normalization.
+    Note that if the detected `base_matrix`==`X`, we'll change the name to `counts` instead.
 
     Examples
     --------
@@ -325,19 +393,154 @@ def log_norm(
     """
     if isinstance(data, MultimodalData):
         data = data.current_data()
-
-    assert data.get_modality() in  {"rna", "visium"}
-
-    if backup_matrix not in data.list_keys():
-        data.add_matrix(backup_matrix, data.X)
-        data.X = data.X.astype(np.float32)  # force copy
-    else:
-        # The case of rerunning log_norm. Use backup matrix as source.
-        data.X = data.get_matrix(backup_matrix).astype(np.float32)  # force copy
-        logger.warning("Rerun log-normalization. Use the raw counts in backup instead.")
-
-    data.obs["scale"] = normalize_by_count(data.X, data.var["robust"].values, norm_count, True)
+    X, base_matrix = _get_base_mat(data, base_matrix)
+    selected_features = _select_features(data)
+    data.obs["scale"] = _normalize_by_count(X, selected_features, norm_count)
     data.uns["norm_count"] = norm_count
+    X = _log1p(X)
+    _set_target_mat(data, X, target_matrix, select, base_matrix, "log_norm")
+
+
+@timer(logger=logger)
+def normalize(
+    data: Union[MultimodalData, UnimodalData],
+    norm_count: float = 1e5,
+    base_matrix: str = None,
+    target_matrix: str = None,
+    select: bool = True,
+) -> None:
+    """Normalize each cell by total count.
+
+    Parameters
+    ----------
+    data: ``pegasusio.MultimodalData``
+        Use current selected modality in data, which should contain one RNA expression matrix.
+
+    norm_count: ``int``, optional, default: ``1e5``.
+        Total counts of one cell after normalization.
+
+    base_matrix: ``str``, optional, default: ``None``.
+        The key name of the matrix to perform normalize. If None, the current matrix.
+
+    target_matrix: ``str``, optional, default: ``None``.
+        The key name of the matrix to store the normalize results. If None, base_matrix + ".norm".
+
+    select: ``bool``, optional, default: ``None``.
+        Select the normalized matrix as the current matrix (can be accessed via data.X).
+
+    Returns
+    -------
+    ``None``
+
+    Add the normalized matrix to ``data.matrices``. Add the normalization scale vector to ``data.obs["scale"]`` and ``norm_count`` parameter to ``data.uns["norm_count"]``.
+
+    Note that if the detected `base_matrix`==`X`, we'll change the name to `counts` instead.
+
+    Examples
+    --------
+    >>> pg.normalize(data)
+    """
+    if isinstance(data, MultimodalData):
+        data = data.current_data()
+    X, base_matrix = _get_base_mat(data, base_matrix)
+    selected_features = _select_features(data)
+    data.obs["scale"] = _normalize_by_count(X, selected_features, norm_count)
+    data.uns["norm_count"] = norm_count
+    _set_target_mat(data, X, target_matrix, select, base_matrix, "norm")
+
+
+@timer(logger=logger)
+def log1p(
+    data: Union[MultimodalData, UnimodalData],
+    base_matrix: str = None,
+    target_matrix: str = None,
+    select: bool = True,
+) -> None:
+    """Apply the Log(1+x) transformation on the given count matrix.
+
+    Parameters
+    ----------
+    data: ``pegasusio.MultimodalData``
+        Use current selected modality in data, which should contain one RNA expression matrix.
+
+    base_matrix: ``str``, optional, default: ``None``.
+        The key name of the matrix to perform the transformation. If None, the current matrix.
+
+    target_matrix: ``str``, optional, default: ``None``.
+        The key name of the matrix to store the transformed results. If None, base_matrix + ".log1p".
+
+    select: ``bool``, optional, default: ``None``.
+        Select the transformed matrix as the current matrix (can be accessed via data.X).
+
+    Returns
+    -------
+    ``None``
+
+    Add the log1p matrix to ``data.matrices``.
+
+    Note that if the detected `base_matrix`==`X`, we'll change the name to `counts` instead.
+
+    Examples
+    --------
+    >>> pg.log1p(data)
+    """
+    if isinstance(data, MultimodalData):
+        data = data.current_data()
+    X, base_matrix = _get_base_mat(data, base_matrix)
+    X = _log1p(X)
+    _set_target_mat(data, X, target_matrix, select, base_matrix, "log1p")
+
+
+@timer(logger=logger)
+def arcsinh(data: Union[MultimodalData, UnimodalData],
+    cofactor: float = 5.0,
+    jitter = False,
+    random_state = 0,
+    base_matrix: str = None,
+    target_matrix: str = None,
+    select: bool = True,
+) -> None:
+    """Conduct arcsinh transform on the current matrix.
+
+    If jitter == True, jittering by adding a randomized value in U([-0.5, 0.5)). This will also make the matrix dense. Mimic Cytobank.
+
+    Parameters
+    ----------
+    cofactor: ``float``, optional, default: ``5.0``
+        Cofactor used in cytobank, arcsinh(x / cofactor).
+
+    jitter: ``bool``, optional, default: ``False``
+        Add a 'arcsinh.jitter' matrix in dense format, jittering by adding a randomized value in U([-0.5, 0.5)).
+
+    random_state: ``int``, optional, default: ``0``
+        Random seed for generating jitters.
+
+    base_matrix: ``str``, optional, default: ``None``.
+        The key name of the matrix to perform arcsinh. If None, the current matrix.
+
+    target_matrix: ``str``, optional, default: ``None``.
+        The key name of the matrix to store the arcsinh results. If None, base_matrix + ".arcsinh".
+
+    select: ``bool``, optional, default: ``None``.
+        Select the arcsinh matrix as the current matrix (can be accessed via data.X).
+
+    Returns
+    -------
+    ``None``
+
+    Add the arcsinh matrix to ``data.matrices``.
+
+    Note that if the detected `base_matrix`==`X`, we'll change the name to `counts` instead.
+
+    Examples
+    --------
+    >>> pg.arcsinh(data)
+    """
+    if isinstance(data, MultimodalData):
+        data = data.current_data()
+    X, base_matrix = _get_base_mat(data, base_matrix)
+    X = _arcsinh(X, jitter, cofactor, random_state)
+    _set_target_mat(data, X, target_matrix, select, base_matrix, "arcsinh")
 
 
 @run_gc
@@ -379,10 +582,10 @@ def select_features(
             X = data.X[:, data.var[features].values]
         else:
             X = data.X
-        
+
         from pegasus.tools import slicing
         X = slicing(X, copy=True)
-        
+
     if standardize:
         m1 = X.mean(axis=0)
         psum = np.multiply(X, X).sum(axis=0)
@@ -428,7 +631,7 @@ def pca(
         Number of Principal Components to get.
 
     features: ``str``, optional, default: ``"highly_variable_features"``.
-        Keyword in ``data.var`` to specify features used for PCA.
+        Keyword in ``data.var`` to specify features used for PCA. If ``None``, all features will be selected.
 
     standardize: ``bool``, optional, default: ``True``.
         Whether to scale the data to unit variance and zero mean.
@@ -509,7 +712,8 @@ def pc_transform(
 
     # normalize and log transform X
     X = X.astype(np.float32) # convert to float
-    _ = normalize_by_count(X, data.var["robust"].values, data.uns["norm_count"], True)
+    _ = _normalize_by_count(X, data.var["robust"].values, data.uns["norm_count"])
+    X = _log1p(X)
 
     # select features
     if data.uns["pca_features"] is not None:
@@ -685,7 +889,8 @@ def tsvd_transform(
 
     # normalize and log transform X
     X = X.astype(np.float32) # convert to float
-    _ = normalize_by_count(X, data.var["robust"].values, data.uns["norm_count"], True)
+    _ = _normalize_by_count(X, data.var["robust"].values, data.uns["norm_count"])
+    X = _log1p(X)
 
     # select features
     if (data.uns["tsvd_features"] is not None) and (data.var[data.uns["tsvd_features"]].sum() < X.shape[1]):
